[Bf-blender-cvs] [58c9a0b] master: Cleanup: spelling

Campbell Barton noreply at git.blender.org
Sat Aug 22 13:23:00 CEST 2015


Commit: 58c9a0b11a0e705f68d741107faba51d9d17000e
Author: Campbell Barton
Date:   Sat Aug 22 21:17:32 2015 +1000
Branches: master
https://developer.blender.org/rB58c9a0b11a0e705f68d741107faba51d9d17000e

Cleanup: spelling

===================================================================

M	source/blender/blenlib/intern/BLI_dynstr.c
M	source/blender/blenlib/intern/math_geom.c
M	source/blender/bmesh/tools/bmesh_bevel.c
M	source/blender/editors/animation/anim_filter.c
M	source/blender/editors/sculpt_paint/paint_image_proj.c
M	source/blender/python/mathutils/mathutils_bvhtree.c
M	source/blender/python/mathutils/mathutils_geometry.c
M	source/gameengine/Rasterizer/RAS_texmatrix.cpp

===================================================================

diff --git a/source/blender/blenlib/intern/BLI_dynstr.c b/source/blender/blenlib/intern/BLI_dynstr.c
index 80cbce7..ecd4a6e 100644
--- a/source/blender/blenlib/intern/BLI_dynstr.c
+++ b/source/blender/blenlib/intern/BLI_dynstr.c
@@ -258,7 +258,7 @@ int BLI_dynstr_get_len(DynStr *ds)
 
 /**
  * Get a DynStr's contents as a c-string.
- * he \a rets argument must be allocated to be at
+ * The \a rets argument must be allocated to be at
  * least the size of ``BLI_dynstr_get_len(ds) + 1``.
  *
  * \param ds: The DynStr of interest.
diff --git a/source/blender/blenlib/intern/math_geom.c b/source/blender/blenlib/intern/math_geom.c
index 0d02ff3..d6029c9 100644
--- a/source/blender/blenlib/intern/math_geom.c
+++ b/source/blender/blenlib/intern/math_geom.c
@@ -573,7 +573,7 @@ float dist_signed_squared_to_corner_v3v3v3(
 	dist_a = dist_signed_squared_to_plane_v3(p, plane_a);
 	dist_b = dist_signed_squared_to_plane_v3(p, plane_b);
 #else
-	/* calculate without he planes 4th component to avoid float precision issues */
+	/* calculate without the planes 4th component to avoid float precision issues */
 	sub_v3_v3v3(s_p_v2, p, v2);
 
 	dist_a = dist_signed_squared_to_plane3_v3(s_p_v2, plane_a);
@@ -1960,7 +1960,7 @@ bool isect_axial_line_tri_v3(const int axis, const float p1[3], const float p2[3
 
 /**
  * \return The number of point of interests
- * 0 - lines are colinear
+ * 0 - lines are collinear
  * 1 - lines are coplanar, i1 is set to intersection
  * 2 - i1 and i2 are the nearest points on line 1 (v1, v2) and line 2 (v3, v4) respectively
  */
diff --git a/source/blender/bmesh/tools/bmesh_bevel.c b/source/blender/bmesh/tools/bmesh_bevel.c
index 3eeb68d..e20d4e6 100644
--- a/source/blender/bmesh/tools/bmesh_bevel.c
+++ b/source/blender/bmesh/tools/bmesh_bevel.c
@@ -792,7 +792,7 @@ static void offset_meet(EdgeHalf *e1, EdgeHalf *e2, BMVert *v, BMFace *f, bool e
 		/* intersect the lines */
 		isect_kind = isect_line_line_v3(off1a, off1b, off2a, off2b, meetco, isect2);
 		if (isect_kind == 0) {
-			/* lines are colinear: we already tested for this, but this used a different epsilon */
+			/* lines are collinear: we already tested for this, but this used a different epsilon */
 			copy_v3_v3(meetco, off1a);  /* just to do something */
 			d = dist_to_line_v3(meetco, v->co, BM_edge_other_vert(e2->e, v)->co);
 			if (fabsf(d - e2->offset_l) > BEVEL_EPSILON)
diff --git a/source/blender/editors/animation/anim_filter.c b/source/blender/editors/animation/anim_filter.c
index ca8a35e..8853422 100644
--- a/source/blender/editors/animation/anim_filter.c
+++ b/source/blender/editors/animation/anim_filter.c
@@ -1429,7 +1429,7 @@ static size_t animfilter_block_data(bAnimContext *ac, ListBase *anim_data, bDope
 		IdAdtTemplate *iat = (IdAdtTemplate *)id;
 		
 		/* NOTE: this macro is used instead of inlining the logic here, since this sort of filtering is still needed
-		 * in a few places in he rest of the code still - notably for the few cases where special mode-based
+		 * in a few places in the rest of the code still - notably for the few cases where special mode-based
 		 * different types of data expanders are required.
 		 */
 		ANIMDATA_FILTER_CASES(iat,
diff --git a/source/blender/python/mathutils/mathutils_bvhtree.c b/source/blender/python/mathutils/mathutils_bvhtree.c
index 506b647..a207b63 100644
--- a/source/blender/python/mathutils/mathutils_bvhtree.c
+++ b/source/blender/python/mathutils/mathutils_bvhtree.c
@@ -522,8 +522,8 @@ static PyObject *py_bvhtree_overlap(PyBVHTree *self, PyBVHTree *other)
 
 			item = PyTuple_New(2);
 			PyTuple_SET_ITEMS(item,
-					PyLong_FromLong(overlap[i].indexA),
-					PyLong_FromLong(overlap[i].indexB));
+			        PyLong_FromLong(overlap[i].indexA),
+			        PyLong_FromLong(overlap[i].indexB));
 
 			PyList_Append(ret, item);
 			Py_DECREF(item);
diff --git a/source/blender/python/mathutils/mathutils_geometry.c b/source/blender/python/mathutils/mathutils_geometry.c
index 2684371..81d0009 100644
--- a/source/blender/python/mathutils/mathutils_geometry.c
+++ b/source/blender/python/mathutils/mathutils_geometry.c
@@ -203,7 +203,7 @@ static PyObject *M_Geometry_intersect_line_line(PyObject *UNUSED(self), PyObject
 	}
 
 	if (result == 0) {
-		/* colinear */
+		/* collinear */
 		Py_RETURN_NONE;
 	}
 	else {
diff --git a/source/gameengine/Rasterizer/RAS_texmatrix.cpp b/source/gameengine/Rasterizer/RAS_texmatrix.cpp
index 3203fcf..d30a3d3 100644
--- a/source/gameengine/Rasterizer/RAS_texmatrix.cpp
+++ b/source/gameengine/Rasterizer/RAS_texmatrix.cpp
@@ -34,7 +34,7 @@
 
 void RAS_CalcTexMatrix(RAS_TexVert p[3],MT_Point3& origin,MT_Vector3& udir,MT_Vector3& vdir)
 {
-// precondition: 3 vertices are non-colinear
+// precondition: 3 vertices are non-collinear
 
 	MT_Vector3 vec1 = p[1].xyz()-p[0].xyz();
 	MT_Vector3 vec2 = p[2].xyz()-p[0].xyz();




More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/editors/sculpt_paint/paint_image_proj.c b/source/blender/editors/sculpt_paint/paint_image_proj.c
index 33ea3ce..2b0aba9 100644
--- a/source/blender/editors/sculpt_paint/paint_image_proj.c
+++ b/source/blender/editors/sculpt_paint/paint_image_proj.c
@@ -2038,16 +2038,16 @@ static void project_bucket_clip_face(
 	int inside_bucket_flag = 0;
 	int inside_face_flag = 0;
 	int flip;
-	bool colinear = false;
+	bool collinear = false;
 	
 	float bucket_bounds_ss[4][2];
 
 	/* detect pathological case where face the three vertices are almost colinear in screen space.
 	 * mostly those will be culled but when flood filling or with smooth shading it's a possibility */
 	if (dist_squared_to_line_v2(v1coSS, v2coSS, v3coSS) < 0.5f ||
 	    dist_squared_to_line_v2(v2coSS, v3coSS, v1coSS) < 0.5f)
 	{
-		colinear = true;
+		collinear = true;
 	}
 	
 	/* get the UV space bounding box */
@@ -2077,7 +2077,7 @@ static void project_bucket_clip_face(
 		return;
 	}
 	/* handle pathological case here, no need for further intersections below since tringle area is almost zero */
-	if (colinear) {
+	if (collinear) {
 		int flag;
 		
 		(*tot) = 0;
@@ -2038,16 +2038,16 @@ static void project_bucket_clip_face(
 	float bucket_bounds_ss[4][2];
 
-	/* detect pathological case where face the three vertices are almost colinear in screen space.
+	/* detect pathological case where face the three vertices are almost collinear in screen space.
 	 * mostly those will be culled but when flood filling or with smooth shading it's a possibility */
 	if (dist_squared_to_line_v2(v1coSS, v2coSS, v3coSS) < 0.5f ||